@@ -1,25 +1,18 @@
 /****************************************************************************
-** Copyright (C) 2010-2018 Klaralvdalens Datakonsult AB, a KDAB Group company, info@kdab.com.
-** All rights reserved.
 **
 ** This file is part of the KD Soap library.
 **
+** SPDX-FileCopyrightText: 2010-2021 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+**
+** SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDAB-KDSoap OR LicenseRef-KDAB-KDSoap-US
+**
 ** Licensees holding valid commercial KD Soap licenses may use this file in
 ** accordance with the KD Soap Commercial License Agreement provided with
 ** the Software.
 **
+** Contact info@kdab.com if any conditions of this licensing are not clear to you.
 **
-** This file may be distributed and/or modified under the terms of the
-** GNU Lesser General Public License version 2.1 and version 3 as published by the
-** Free Software Foundation and appearing in the file LICENSE.LGPL.txt included.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-**
-** Contact info@kdab.com if any conditions of this licensing are not
-** clear to you.
-**
-**********************************************************************/
+****************************************************************************/
 #ifndef KDSOAPMESSAGE_H
 #define KDSOAPMESSAGE_H
 
@@ -100,7 +93,8 @@ public:
      *
      * If the message isQualified(), the value will be set to qualified as well, for convenience.
      */
-    void addArgument(const QString &argumentName, const QVariant &argumentValue, const QString &typeNameSpace = QString(), const QString &typeName = QString());
+    void addArgument(const QString &argumentName, const QVariant &argumentValue, const QString &typeNameSpace = QString(),
+                     const QString &typeName = QString());
 
     /**
      * Adds a complex-type argument to the message.
@@ -117,7 +111,8 @@ public:
      *
      * If the message isQualified(), the value will be set to qualified as well, for convenience.
      */
-    void addArgument(const QString &argumentName, const KDSoapValueList &argumentValueList, const QString &typeNameSpace = QString(), const QString &typeName = QString());
+    void addArgument(const QString &argumentName, const KDSoapValueList &argumentValueList, const QString &typeNameSpace = QString(),
+                     const QString &typeName = QString());
 
     /**
      * Returns the arguments for the message.
@@ -151,6 +146,14 @@ public:
      */
     void setFault(bool fault);
 
+    /**
+     * Turns this message into a "fault" message, using the given code and description.
+     * This encapsulates the differences between SOAP 1.1 and 1.2.
+     * Used internally, and by server implementations that handle dynamic calls
+     * \since 1.8
+     */
+    void createFaultMessage(const QString &faultCode, const QString &faultText, KDSoap::SoapVersion soapVersion);
+
     /**
      * Attach to a KDSoapMessage the message addressing properties that will be written
      * in its header.
@@ -172,6 +175,7 @@ public:
      * \since 1.5
      */
     KDSoapMessageAddressingProperties messageAddressingProperties() const;
+
 private:
     bool isNull() const;
     friend class KDSoapPendingCall;
@@ -184,7 +188,7 @@ private:
  * Set of headers that can be provided when making a SOAP call.
  * \see KDSoapClientInterface
  */
-class KDSOAP_EXPORT KDSoapHeaders : public QList<KDSoapMessage> //krazy:exclude=dpointer
+class KDSOAP_EXPORT KDSoapHeaders : public QList<KDSoapMessage> // krazy:exclude=dpointer
 {
 public:
     /**
@@ -204,5 +208,6 @@ public:
 KDSOAP_EXPORT QDebug operator<<(QDebug dbg, const KDSoapMessage &msg);
 
 Q_DECLARE_METATYPE(KDSoapMessage)
+Q_DECLARE_METATYPE(KDSoapHeaders)
 
 #endif // KDSOAPMESSAGE_H
